@@ -16,6 +16,7 @@ from vitrage.api.controllers.v1 import event
 from vitrage.api.controllers.v1 import rca
 from vitrage.api.controllers.v1 import resource
 from vitrage.api.controllers.v1 import service
+from vitrage.api.controllers.v1 import status
 from vitrage.api.controllers.v1 import template
 from vitrage.api.controllers.v1 import topology
 from vitrage.api.controllers.v1 import webhook
@@ -33,3 +34,4 @@ class V1Controller(object):
     template = template.TemplateController()
     event = event.EventController()
     service = service.ServiceController()
+    status = status.StatusController()
