@@ -31,9 +31,6 @@ LOG = log.getLogger(__name__)
                     info={}, hide_args=False, trace_private=False)
 class ResourceApis(base.EntityGraphApisBase):
 
-    def __init__(self, entity_graph, conf, api_lock):
-        super(ResourceApis, self).__init__(entity_graph, conf, api_lock)
-
     @timed_method(log_results=True)
     @base.lock_graph
     def get_resources(self, ctx, resource_type=None, all_tenants=False,
@@ -71,7 +68,7 @@ class ResourceApis(base.EntityGraphApisBase):
         return json.dumps(counts)
 
     def _get_query(self, ctx, resource_type, all_tenants, query_dict):
-        project_id = ctx.get(TenantProps.TENANT, None)
+        project_id = ctx.get(TenantProps.PROJECT_ID, None)
         is_admin_project = ctx.get(TenantProps.IS_ADMIN, False)
 
         if all_tenants:
@@ -102,7 +99,7 @@ class ResourceApis(base.EntityGraphApisBase):
             return None
 
         is_admin = ctx.get(TenantProps.IS_ADMIN, False)
-        curr_project = ctx.get(TenantProps.TENANT, None)
+        curr_project = ctx.get(TenantProps.PROJECT_ID, None)
         resource_project = resource.get(VProps.PROJECT_ID)
         if not is_admin and curr_project != resource_project:
             LOG.warning('Resource show - Authorization failed (%s)',
