@@ -32,17 +32,16 @@ LOG = log.getLogger(__name__)
 
 class CeilometerDriver(AlarmDriverBase):
 
-    def __init__(self, conf):
+    def __init__(self):
         super(CeilometerDriver, self).__init__()
         self._client = None
-        self.conf = conf
         self._init_aodh_event_actions()
         self._cache_all_alarms()
 
     @property
     def client(self):
         if not self._client:
-            self._client = os_clients.ceilometer_client(self.conf)
+            self._client = os_clients.ceilometer_client()
         return self._client
 
     def _vitrage_type(self):
@@ -182,7 +181,7 @@ class CeilometerDriver(AlarmDriverBase):
     def _convert_alarm(cls, alarm):
         alarm_type = alarm.type
         if alarm_type == CeilProps.EVENT and \
-            _is_vitrage_alarm(alarm.event_rule):
+                _is_vitrage_alarm(alarm.event_rule):
             return cls._convert_vitrage_alarm(alarm)
         elif alarm_type == CeilProps.EVENT:
             return cls._convert_event_alarm(alarm)
@@ -314,6 +313,10 @@ class CeilometerDriver(AlarmDriverBase):
 
         return entity
 
+    @staticmethod
+    def should_delete_outdated_entities():
+        return True
+
     def _convert_alarm_creation_event(self, event):
         entity = self._convert_base_event(event)
         detail = self._convert_detail_event(event)
@@ -345,7 +348,7 @@ class CeilometerDriver(AlarmDriverBase):
                 entity.update(self._parse_changed_rule(
                     changed_rule[changed_type]))
             # handle other changed alarm properties
-            elif changed_type in CeilProps.__dict__.values():
+            elif changed_type in vars(CeilProps).values():
                 entity[changed_type] = changed_info
 
         return self._filter_and_cache_alarm(entity, old_alarm,
