@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import absolute_import
-
 import pytz
 import sqlalchemy
 from sqlalchemy import and_
@@ -23,7 +21,7 @@ from oslo_db.sqlalchemy import utils as sqlalchemyutils
 from oslo_log import log
 from oslo_utils import timeutils
 
-from vitrage.common.constants import EdgeLabel as ELable
+from vitrage.common.constants import EdgeLabel as ELabel
 from vitrage.common.constants import HistoryProps as HProps
 from vitrage.common.exception import VitrageInputError
 from vitrage.entity_graph.mappings.operational_alarm_severity import \
@@ -253,7 +251,7 @@ class HistoryFacadeConnection(object):
                                     "'filter_by' and 'filter_vals' differs")
         for d in sort_dirs:
             if d not in (ASC, DESC):
-                raise VitrageInputError("Unknown sort direction %s", str(d))
+                raise VitrageInputError("Unknown sort direction %s" % d)
 
     @staticmethod
     def _add_time_frame_to_query(query, start, end):
@@ -399,7 +397,7 @@ class HistoryFacadeConnection(object):
         session = self._engine_facade.get_session()
         query = session.query(models.Edge)\
             .filter(and_(getattr(models.Edge, filter_by).in_(alarm_ids),
-                         models.Edge.label == ELable.CAUSES))
+                         models.Edge.label == ELabel.CAUSES))
 
         query = query.join(models.Edge.target)
         query = self._add_project_filtering_to_query(query, proj_id, admin)
